@@ -32,9 +32,8 @@
 #include <string.h>
 #endif
 
-#include <thunar-sbr/thunar-sbr-number-renamer.h>
-
 #include <libxfce4util/libxfce4util.h>
+#include <thunar-sbr/thunar-sbr-number-renamer.h>
 
 
 
@@ -50,21 +49,27 @@ enum
 
 
 
-static void   thunar_sbr_number_renamer_finalize      (GObject                      *object);
-static void   thunar_sbr_number_renamer_get_property  (GObject                      *object,
-                                                       guint                         prop_id,
-                                                       GValue                       *value,
-                                                       GParamSpec                   *pspec);
-static void   thunar_sbr_number_renamer_set_property  (GObject                      *object,
-                                                       guint                         prop_id,
-                                                       const GValue                 *value,
-                                                       GParamSpec                   *pspec);
-static void   thunar_sbr_number_renamer_realize       (GtkWidget                    *widget);
-static gchar *thunar_sbr_number_renamer_process       (ThunarxRenamer               *renamer,
-                                                       ThunarxFileInfo              *file,
-                                                       const gchar                  *text,
-                                                       guint                         idx);
-static void   thunar_sbr_number_renamer_update        (ThunarSbrNumberRenamer       *number_renamer);
+static void
+thunar_sbr_number_renamer_finalize (GObject *object);
+static void
+thunar_sbr_number_renamer_get_property (GObject    *object,
+                                        guint       prop_id,
+                                        GValue     *value,
+                                        GParamSpec *pspec);
+static void
+thunar_sbr_number_renamer_set_property (GObject      *object,
+                                        guint         prop_id,
+                                        const GValue *value,
+                                        GParamSpec   *pspec);
+static void
+thunar_sbr_number_renamer_realize (GtkWidget *widget);
+static gchar *
+thunar_sbr_number_renamer_process (ThunarxRenamer  *renamer,
+                                   ThunarxFileInfo *file,
+                                   const gchar     *text,
+                                   guint            idx);
+static void
+thunar_sbr_number_renamer_update (ThunarSbrNumberRenamer *number_renamer);
 
 
 
@@ -75,9 +80,9 @@ struct _ThunarSbrNumberRenamerClass
 
 struct _ThunarSbrNumberRenamer
 {
-  ThunarxRenamer      __parent__;
+  ThunarxRenamer __parent__;
 
-  GtkWidget          *start_entry;
+  GtkWidget *start_entry;
 
   ThunarSbrNumberMode mode;
   gchar              *start;
@@ -203,6 +208,7 @@ thunar_sbr_number_renamer_init (ThunarSbrNumberRenamer *number_renamer)
   relation = atk_relation_new (&object, 1, ATK_RELATION_LABEL_FOR);
   atk_relation_set_add (relations, relation);
   g_object_unref (G_OBJECT (relation));
+  g_object_unref (relations);
 
   number_renamer->start_entry = gtk_entry_new ();
   gtk_entry_set_max_length (GTK_ENTRY (number_renamer->start_entry), 8);
@@ -225,6 +231,7 @@ thunar_sbr_number_renamer_init (ThunarSbrNumberRenamer *number_renamer)
   relation = atk_relation_new (&object, 1, ATK_RELATION_LABEL_FOR);
   atk_relation_set_add (relations, relation);
   g_object_unref (G_OBJECT (relation));
+  g_object_unref (relations);
 
   label = gtk_label_new_with_mnemonic (_("Text _Format:"));
   gtk_grid_attach (GTK_GRID (grid), label, 0, 1, 1, 1);
@@ -246,6 +253,7 @@ thunar_sbr_number_renamer_init (ThunarSbrNumberRenamer *number_renamer)
   relation = atk_relation_new (&object, 1, ATK_RELATION_LABEL_FOR);
   atk_relation_set_add (relations, relation);
   g_object_unref (G_OBJECT (relation));
+  g_object_unref (relations);
 
   entry = gtk_entry_new ();
   gtk_entry_set_width_chars (GTK_ENTRY (entry), 12);
@@ -266,6 +274,7 @@ thunar_sbr_number_renamer_init (ThunarSbrNumberRenamer *number_renamer)
   relation = atk_relation_new (&object, 1, ATK_RELATION_LABEL_FOR);
   atk_relation_set_add (relations, relation);
   g_object_unref (G_OBJECT (relation));
+  g_object_unref (relations);
 }
 
 
@@ -364,7 +373,7 @@ thunar_sbr_number_renamer_realize (GtkWidget *widget)
 
 
 
-static gchar*
+static gchar *
 thunar_sbr_number_renamer_process (ThunarxRenamer  *renamer,
                                    ThunarxFileInfo *file,
                                    const gchar     *text,
@@ -389,8 +398,8 @@ thunar_sbr_number_renamer_process (ThunarxRenamer  *renamer,
       /* "start" property must be 'a', 'b', 'c', etc. */
       start = *number_renamer->start;
       invalid = (strlen (number_renamer->start) != 1
-              || g_unichar_tolower (start) < 'a'
-              || g_unichar_tolower (start) > 'z');
+                 || g_unichar_tolower (start) < 'a'
+                 || g_unichar_tolower (start) > 'z');
     }
 
   /* check if we have invalid settings */
@@ -470,8 +479,8 @@ thunar_sbr_number_renamer_process (ThunarxRenamer  *renamer,
 static void
 thunar_sbr_number_renamer_update (ThunarSbrNumberRenamer *number_renamer)
 {
-  gboolean  invalid = TRUE;
-  gchar    *endp;
+  gboolean invalid = TRUE;
+  gchar   *endp;
 
   /* check whether "start" is valid for the "mode" */
   if (number_renamer->mode < THUNAR_SBR_NUMBER_MODE_ABC)
@@ -484,8 +493,8 @@ thunar_sbr_number_renamer_update (ThunarSbrNumberRenamer *number_renamer)
     {
       /* "start" property must be 'a', 'b', 'c', etc. */
       invalid = (strlen (number_renamer->start) != 1
-              || g_unichar_tolower (*number_renamer->start) < 'a'
-              || g_unichar_tolower (*number_renamer->start) > 'z');
+                 || g_unichar_tolower (*number_renamer->start) < 'a'
+                 || g_unichar_tolower (*number_renamer->start) > 'z');
     }
 
   /* check if the start entry is realized */
@@ -493,9 +502,9 @@ thunar_sbr_number_renamer_update (ThunarSbrNumberRenamer *number_renamer)
     {
       /* highlight invalid input by using theme specific colors */
       if (G_UNLIKELY (invalid))
-          gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (number_renamer->start_entry)), "error");
+        gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (number_renamer->start_entry)), "error");
       else
-          gtk_style_context_remove_class (gtk_widget_get_style_context (GTK_WIDGET (number_renamer->start_entry)), "error");
+        gtk_style_context_remove_class (gtk_widget_get_style_context (GTK_WIDGET (number_renamer->start_entry)), "error");
     }
 
   /* notify everybody that we have a new state */
@@ -511,7 +520,7 @@ thunar_sbr_number_renamer_update (ThunarSbrNumberRenamer *number_renamer)
  *
  * Return value: the newly allocated #ThunarSbrNumberRenamer.
  **/
-ThunarSbrNumberRenamer*
+ThunarSbrNumberRenamer *
 thunar_sbr_number_renamer_new (void)
 {
   return g_object_new (THUNAR_SBR_TYPE_NUMBER_RENAMER,
@@ -575,7 +584,7 @@ thunar_sbr_number_renamer_set_mode (ThunarSbrNumberRenamer *number_renamer,
  *
  * Return value: the start for @number_renamer.
  **/
-const gchar*
+const gchar *
 thunar_sbr_number_renamer_get_start (ThunarSbrNumberRenamer *number_renamer)
 {
   g_return_val_if_fail (THUNAR_SBR_IS_NUMBER_RENAMER (number_renamer), NULL);
@@ -622,7 +631,7 @@ thunar_sbr_number_renamer_set_start (ThunarSbrNumberRenamer *number_renamer,
  *
  * Return value: the text for @number_renamer.
  **/
-const gchar*
+const gchar *
 thunar_sbr_number_renamer_get_text (ThunarSbrNumberRenamer *number_renamer)
 {
   g_return_val_if_fail (THUNAR_SBR_IS_NUMBER_RENAMER (number_renamer), NULL);
@@ -704,7 +713,3 @@ thunar_sbr_number_renamer_set_text_mode (ThunarSbrNumberRenamer *number_renamer,
       g_object_notify (G_OBJECT (number_renamer), "text-mode");
     }
 }
-
-
-
-
